@@ -826,48 +826,91 @@ ideogram <- function(karyotype, overlaid = NULL, label = NULL, label_type = NULL
           mydata_interval$x <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value * chr_width / max(mydata_interval$Value)
           mydata_interval$y <- apply(data.frame(mydata_interval$ChrEnd,mydata_interval$Start,mydata_interval$End),1,function(x)(((25+maxchrlen*(1-(x[1]-x[2])/max(karyotype$End))) * mpx + (25+maxchrlen*(1-(x[1]-x[3])/max(karyotype$End))) * mpx)/2))
           mydata_interval$point <- paste(mydata_interval$x, mydata_interval$y, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
-              karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+          if (col_num == 3){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
+                karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+              }
+              karyotype[i, 29] <- paste("<polyline points=\"",
+                                        karyotype[i, 29],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
             }
-            karyotype[i, 29] <- paste("<polyline points=\"",
-                                      karyotype[i, 29],
-                                      "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
+            colnames(karyotype)[29] <- "line"
+          } else if (col_num == 5){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 35] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
+                karyotype[i, 35] <- paste(karyotype[i, 35], tmp, sep = " ")
+              }
+              karyotype[i, 35] <- paste("<polyline points=\"",
+                                        karyotype[i, 35],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
+            }
+            colnames(karyotype)[35] <- "line"
           }
-          colnames(karyotype)[29] <- "line"
         } else if (ncol(mydata_interval) == 7){
           mydata_interval <- merge(mydata_interval, data.frame(Chr = karyotype$Chr, ChrEnd = karyotype$End, x = karyotype$x1), by="Chr")
           mydata_interval$x1 <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value_1 * chr_width / max(mydata_interval$Value_1)
           mydata_interval$y1 <- apply(data.frame(mydata_interval$ChrEnd,mydata_interval$Start,mydata_interval$End),1,function(x)(((25+maxchrlen*(1-(x[1]-x[2])/max(karyotype$End))) * mpx + (25+maxchrlen*(1-(x[1]-x[3])/max(karyotype$End))) * mpx)/2))
           mydata_interval$point1 <- paste(mydata_interval$x1, mydata_interval$y1, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
-              karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+          if (col_num == 3){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
+                karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+              }
+              karyotype[i, 29] <- paste("<polyline points=\"",
+                                        karyotype[i, 29],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
             }
-            karyotype[i, 29] <- paste("<polyline points=\"",
-                                      karyotype[i, 29],
-                                      "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
-          }
-          colnames(karyotype)[29] <- "line1"
-
-          mydata_interval$x2 <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
-          mydata_interval$y2 <- mydata_interval$y1
-          mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 30] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
-              karyotype[i, 30] <- paste(karyotype[i, 30], tmp, sep = " ")
+            colnames(karyotype)[29] <- "line1"
+            
+            mydata_interval$x2 <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
+            mydata_interval$y2 <- mydata_interval$y1
+            mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 30] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
+                karyotype[i, 30] <- paste(karyotype[i, 30], tmp, sep = " ")
+              }
+              karyotype[i, 30] <- paste("<polyline points=\"",
+                                        karyotype[i, 30],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,7], "; stroke-width:1\"/>", sep = "")
             }
-            karyotype[i, 30] <- paste("<polyline points=\"",
-                                      karyotype[i, 30],
-                                      "\" style=\"fill:none; stroke:#", mydata_interval[1,7], "; stroke-width:1\"/>", sep = "")
+            colnames(karyotype)[30] <- "line2"
+          } else if (col_num == 5){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 35] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
+                karyotype[i, 35] <- paste(karyotype[i, 35], tmp, sep = " ")
+              }
+              karyotype[i, 35] <- paste("<polyline points=\"",
+                                        karyotype[i, 35],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,5], "; stroke-width:1\"/>", sep = "")
+            }
+            colnames(karyotype)[35] <- "line1"
+            
+            mydata_interval$x2 <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
+            mydata_interval$y2 <- mydata_interval$y1
+            mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 36] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
+                karyotype[i, 36] <- paste(karyotype[i, 36], tmp, sep = " ")
+              }
+              karyotype[i, 36] <- paste("<polyline points=\"",
+                                        karyotype[i, 36],
+                                        "\" style=\"fill:none; stroke:#", mydata_interval[1,7], "; stroke-width:1\"/>", sep = "")
+            }
+            colnames(karyotype)[36] <- "line2"
           }
-          colnames(karyotype)[30] <- "line2"
         }
       } else if (label_type == "polygon"){
         if (ncol(mydata_interval) == 5){
@@ -875,54 +918,103 @@ ideogram <- function(karyotype, overlaid = NULL, label = NULL, label_type = NULL
           mydata_interval$x <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value * chr_width / max(mydata_interval$Value)
           mydata_interval$y <- apply(data.frame(mydata_interval$ChrEnd,mydata_interval$Start,mydata_interval$End),1,function(x)(((25+maxchrlen*(1-(x[1]-x[2])/max(karyotype$End))) * mpx + (25+maxchrlen*(1-(x[1]-x[3])/max(karyotype$End))) * mpx)/2))
           mydata_interval$point <- paste(mydata_interval$x, mydata_interval$y, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
-              karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+          if (col_num == 3){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
+                karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+              }
+              karyotype[i, 29] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 29],
+                                        paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
             }
-            karyotype[i, 29] <- paste("<polygon points=\"",
-                                      paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
-                                      karyotype[i, 29],
-                                      paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
-                                      "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
+            colnames(karyotype)[29] <- "polygon"
+          } else if (col_num == 5){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 35] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point[j]
+                karyotype[i, 35] <- paste(karyotype[i, 35], tmp, sep = " ")
+              }
+              karyotype[i, 35] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 35],
+                                        paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
+            }
+            colnames(karyotype)[35] <- "polygon"
           }
-          colnames(karyotype)[29] <- "polygon"
         } else if (ncol(mydata_interval) == 7){
           mydata_interval <- merge(mydata_interval, data.frame(Chr = karyotype$Chr, ChrEnd = karyotype$End, x = karyotype$x1), by="Chr")
           mydata_interval$x1 <- mydata_interval$x + 1.2 * chr_width + mydata_interval$Value_1 * chr_width / max(mydata_interval$Value_1)
           mydata_interval$y1 <- apply(data.frame(mydata_interval$ChrEnd,mydata_interval$Start,mydata_interval$End),1,function(x)(((25+maxchrlen*(1-(x[1]-x[2])/max(karyotype$End))) * mpx + (25+maxchrlen*(1-(x[1]-x[3])/max(karyotype$End))) * mpx)/2))
           mydata_interval$point1 <- paste(mydata_interval$x1, mydata_interval$y1, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
-              karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+          if (col_num == 3){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 29] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
+                karyotype[i, 29] <- paste(karyotype[i, 29], tmp, sep = " ")
+              }
+              karyotype[i, 29] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 29],
+                                        paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
             }
-            karyotype[i, 29] <- paste("<polygon points=\"",
-                                      paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
-                                      karyotype[i, 29],
-                                      paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
-                                      "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
-          }
-          colnames(karyotype)[29] <- "polygon1"
-
-          mydata_interval$x2 <- mydata_interval$x + 1.4 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
-          mydata_interval$y2 <- mydata_interval$y1
-          mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
-          for (i in 1:nrow(karyotype)){
-            karyotype[i, 30] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
-            for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
-              tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
-              karyotype[i, 30] <- paste(karyotype[i, 30], tmp, sep = " ")
+            colnames(karyotype)[29] <- "polygon1"
+            
+            mydata_interval$x2 <- mydata_interval$x + 1.4 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
+            mydata_interval$y2 <- mydata_interval$y1
+            mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 30] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
+                karyotype[i, 30] <- paste(karyotype[i, 30], tmp, sep = " ")
+              }
+              karyotype[i, 30] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.4 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 30],
+                                        paste(" ", karyotype$x1[i] + 1.4 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,7], "; stroke:#", mydata_interval[1,7], "; stroke-width:0.25\"/>", sep = "")
             }
-            karyotype[i, 30] <- paste("<polygon points=\"",
-                                      paste(karyotype$x1[i] + 1.4 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
-                                      karyotype[i, 30],
-                                      paste(" ", karyotype$x1[i] + 1.4 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
-                                      "\" style=\"fill:#", mydata_interval[1,7], "; stroke:#", mydata_interval[1,7], "; stroke-width:0.25\"/>", sep = "")
+            colnames(karyotype)[30] <- "polygon2"
+          } else if (col_num == 5){
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 35] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point1[j]
+                karyotype[i, 35] <- paste(karyotype[i, 35], tmp, sep = " ")
+              }
+              karyotype[i, 35] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.2 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 35],
+                                        paste(" ", karyotype$x1[i] + 1.2 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,5], "; stroke:#", mydata_interval[1,5], "; stroke-width:0.25\"/>", sep = "")
+            }
+            colnames(karyotype)[35] <- "polygon1"
+            
+            mydata_interval$x2 <- mydata_interval$x + 1.4 * chr_width + mydata_interval$Value_2 * chr_width / max(mydata_interval$Value_2)
+            mydata_interval$y2 <- mydata_interval$y1
+            mydata_interval$point2 <- paste(mydata_interval$x2, mydata_interval$y2, sep = ",")
+            for (i in 1:nrow(karyotype)){
+              karyotype[i, 36] <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[1]
+              for (j in 2:nrow(subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1]))){
+                tmp <- subset(mydata_interval, mydata_interval$Chr == karyotype[i, 1])$point2[j]
+                karyotype[i, 36] <- paste(karyotype[i, 36], tmp, sep = " ")
+              }
+              karyotype[i, 36] <- paste("<polygon points=\"",
+                                        paste(karyotype$x1[i] + 1.4 * chr_width, ",", karyotype$y1[i] - chr_width/2, " ", sep = ""),
+                                        karyotype[i, 36],
+                                        paste(" ", karyotype$x1[i] + 1.4 * chr_width, ",", (25 + maxchrlen) * mpx, sep = ""),
+                                        "\" style=\"fill:#", mydata_interval[1,7], "; stroke:#", mydata_interval[1,7], "; stroke-width:0.25\"/>", sep = "")
+            }
+            colnames(karyotype)[36] <- "polygon2"
           }
-          colnames(karyotype)[30] <- "polygon2"
         }
       }
     }
